from setuptools import setup

setup(name='test_import_faiss_atran',
      version='0.4',
      description='Basic Test',
      url=' ',
      author='Faisal',
      author_email='muhammad.faisal@altran.com',
      license='',
      packages=['test_import_faiss_atran'],
      zip_safe=False)